@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 
 ###############################################################################
@@ -42,8 +42,18 @@ sub new {
     $self->{_horiz_cat_axis}    = 1;
     $self->{_show_crosses}      = 0;
 
-    bless $self, $class;
+    # Override and reset the default axis values.
+    $self->{_x_axis}->{_defaults}->{major_gridlines} = { visible => 1 };
+    $self->{_y_axis}->{_defaults}->{major_gridlines} = { visible => 0 };
 
+    if ( $self->{_subtype} eq 'percent_stacked' ) {
+        $self->{_x_axis}->{_defaults}->{num_format} = '0%';
+    }
+
+    $self->set_x_axis();
+    $self->set_y_axis();
+
+    bless $self, $class;
     return $self;
 }
 
@@ -60,16 +70,11 @@ sub _write_chart_type {
     my %args = @_;
 
     if ( $args{primary_axes} ) {
-        ## Reverse X and Y axes for Bar charts.
-        my $old_y = $self->{_y_axis};
-        my $old_x = $self->{_x_axis};
 
-        $self->{_y_axis} = $old_x;
-        $self->{_x_axis} = $old_y;
-
-        if ( !$self->{_y_axis}->{_major_gridlines} ) {
-            $self->{_y_axis}->{_major_gridlines} = { show => 1 };
-        }
+        # Reverse X and Y axes for Bar charts.
+        my $tmp = $self->{_y_axis};
+        $self->{_y_axis} = $self->{_x_axis};
+        $self->{_x_axis} = $tmp;
 
         if ( $self->{_y2_axis}->{_position} eq 'r' ) {
             $self->{_y2_axis}->{_position} = 't';
@@ -146,34 +151,6 @@ sub _write_bar_dir {
 }
 
 
-##############################################################################
-#
-# _write_num_fmt()
-#
-# Over-ridden to add % format. TODO. This will be refactored back up to the
-# SUPER class later.
-#
-# Write the <c:numFmt> element.
-#
-sub _write_number_format {
-
-    my $self          = shift;
-    my $format_code   = shift || 'General';
-    my $source_linked = 1;
-
-    if ( $self->{_subtype} eq 'percent_stacked' ) {
-        $format_code = '0%';
-    }
-
-    my @attributes = (
-        'formatCode'   => $format_code,
-        'sourceLinked' => $source_linked,
-    );
-
-    $self->xml_empty_tag( 'c:numFmt', @attributes );
-}
-
-
 1;
 
 
@@ -303,7 +280,7 @@ Here is a complete example that demonstrates most of the available features when
 
 <p>This will produce a chart that looks like this:</p>
 
-<p><center><img src="http://homepage.eircom.net/~jmcnamara/perl/images/2007/bar1.jpg" width="483" height="291" alt="Chart example." /></center></p>
+<p><center><img src="http://jmcnamara.github.com/excel-writer-xlsx/images/examples/bar1.jpg" width="483" height="291" alt="Chart example." /></center></p>
 
 =end html
 
